==> kubernetes-model-1.0.61-sources.jar: io/fabric8/openshift/api/model/SubjectAccessReviewResponseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class SubjectAccessReviewResponseBuilder extends SubjectAccessReviewResponseFluentImpl<SubjectAccessReviewResponseBuilder> implements VisitableBuilder<SubjectAccessReviewResponse,SubjectAccessReviewResponseBuilder>{

    SubjectAccessReviewResponseFluent<?> fluent;
    Boolean validationEnabled;

    public SubjectAccessReviewResponseBuilder(){
            this(true);
    }
    public SubjectAccessReviewResponseBuilder(Boolean validationEnabled){
            this(new SubjectAccessReviewResponse(), validationEnabled);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent){
            this(fluent, true);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SubjectAccessReviewResponse(), validationEnabled);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent,SubjectAccessReviewResponse instance){
            this(fluent, instance, true);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent,SubjectAccessReviewResponse instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAllowed(instance.getAllowed()); 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withEvaluationError(instance.getEvaluationError()); 
            fluent.withKind(instance.getKind()); 
            fluent.withNamespace(instance.getNamespace()); 
            fluent.withReason(instance.getReason()); 
            this.validationEnabled = validationEnabled; 
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponse instance){
            this(instance,true);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponse instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAllowed(instance.getAllowed()); 
            this.withApiVersion(instance.getApiVersion()); 
            this.withEvaluationError(instance.getEvaluationError()); 
            this.withKind(instance.getKind()); 
            this.withNamespace(instance.getNamespace()); 
            this.withReason(instance.getReason()); 
            this.validationEnabled = validationEnabled; 
    }

    public SubjectAccessReviewResponse build(){
            SubjectAccessReviewResponse buildable = new SubjectAccessReviewResponse(fluent.isAllowed(),fluent.getApiVersion(),fluent.getEvaluationError(),fluent.getKind(),fluent.getNamespace(),fluent.getReason());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SubjectAccessReviewResponseBuilder that = (SubjectAccessReviewResponseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/SubjectAccessReviewResponseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class SubjectAccessReviewResponseBuilder extends SubjectAccessReviewResponseFluentImpl<SubjectAccessReviewResponseBuilder> implements VisitableBuilder<SubjectAccessReviewResponse,SubjectAccessReviewResponseBuilder>{

    SubjectAccessReviewResponseFluent<?> fluent;
    Boolean validationEnabled;

    public SubjectAccessReviewResponseBuilder(){
            this(true);
    }
    public SubjectAccessReviewResponseBuilder(Boolean validationEnabled){
            this(new SubjectAccessReviewResponse(), validationEnabled);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent){
            this(fluent, true);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SubjectAccessReviewResponse(), validationEnabled);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent,SubjectAccessReviewResponse instance){
            this(fluent, instance, true);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponseFluent<?> fluent,SubjectAccessReviewResponse instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withAllowed(instance.getAllowed()); 
            fluent.withApiVersion(instance.getApiVersion()); 
            fluent.withEvaluationError(instance.getEvaluationError()); 
            fluent.withKind(instance.getKind()); 
            fluent.withNamespace(instance.getNamespace()); 
            fluent.withReason(instance.getReason()); 
            this.validationEnabled = validationEnabled; 
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponse instance){
            this(instance,true);
    }
    public SubjectAccessReviewResponseBuilder(SubjectAccessReviewResponse instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withAllowed(instance.getAllowed()); 
            this.withApiVersion(instance.getApiVersion()); 
            this.withEvaluationError(instance.getEvaluationError()); 
            this.withKind(instance.getKind()); 
            this.withNamespace(instance.getNamespace()); 
            this.withReason(instance.getReason()); 
            this.validationEnabled = validationEnabled; 
    }

    public SubjectAccessReviewResponse build(){
            SubjectAccessReviewResponse buildable = new SubjectAccessReviewResponse(fluent.isAllowed(),fluent.getApiVersion(),fluent.getEvaluationError(),fluent.getKind(),fluent.getNamespace(),fluent.getReason());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SubjectAccessReviewResponseBuilder that = (SubjectAccessReviewResponseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
